@@ -1,4 +1,4 @@
-PLS_glm <- function(dataY,dataX,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,method,sparse=FALSE,sparseStop=TRUE,naive=FALSE) {  
+PLS_glm <- function(dataY,dataX,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,method,sparse=FALSE,sparseStop=FALSE,naive=FALSE) {  
 
 
 ##################################################
@@ -12,7 +12,7 @@ if(any(apply(is.na(dataX),MARGIN=2,"all"))){return(vector("list",0)); cat("One o
 if(any(apply(is.na(dataX),MARGIN=1,"all"))){return(vector("list",0)); cat("One of the rows of dataX is completely filled with missing data\n"); stop()}
 if(identical(dataPredictY,dataX)){PredYisdataX <- TRUE} else {PredYisdataX <- FALSE}
 if(!PredYisdataX){
-if(any(apply(is.na(dataPredictY),MARGIN=2,"all"))){return(vector("list",0)); cat("One of the columns of dataPredictY is completely filled with missing data\n"); stop()}
+#if(any(apply(is.na(dataPredictY),MARGIN=2,"all"))){return(vector("list",0)); cat("One of the columns of dataPredictY is completely filled with missing data\n"); stop()}
 if(any(apply(is.na(dataPredictY),MARGIN=1,"all"))){return(vector("list",0)); cat("One of the rows of dataPredictY is completely filled with missing data\n"); stop()}
 }
 if(missing(weights)){NoWeights=TRUE} else {if(all(weights==rep(1,length(dataY)))){NoWeights=TRUE} else {NoWeights=FALSE}}
@@ -21,9 +21,10 @@ if(any(is.na(dataX))) {na.miss.X <- TRUE} else na.miss.X <- FALSE
 if(any(is.na(dataY))) {na.miss.Y <- TRUE} else na.miss.Y <- FALSE
 if(any(is.na(dataPredictY))) {na.miss.PredictY <- TRUE} else {na.miss.PredictY <- FALSE}
 if(is.null(modele)){naive=FALSE} else {if(modele=="pls"){naive=FALSE} else {if(!missing(naive)){cat(paste("Only naive DoF can be used with PLS GLM\n",sep=""))}; naive=TRUE}}
-if(na.miss.X|na.miss.Y){naive=TRUE; cat(paste("Only naive DoF can be used with missing data\n",sep="")); if(!NoWeights){cat(paste("Weights cannot be used with missing data\n",sep=""))}}
+if(na.miss.X|na.miss.Y){naive=TRUE; cat(paste("Only naive DoF can be used with missing data\n",sep="")); if(!NoWeights){cat(paste("Weights cannot be used with missing data\n",sep=""))};  if(sparse){cat(paste("sparse option cannot be used with missing data\n",sep="")); sparse=FALSE}}
 if(!NoWeights){naive=TRUE; cat(paste("Only naive DoF can be used with weighted PLS\n",sep=""))} else {NoWeights=TRUE}
-if(sparse){pvals.expli=TRUE}
+if(sparse){sparseStop=TRUE}
+if(sparseStop){pvals.expli=TRUE}
 
 if (!is.data.frame(dataX)) {dataX <- data.frame(dataX)}
 if (is.null(modele) & !is.null(family)) {modele<-"pls-glm-family"}
@@ -172,11 +173,8 @@ tempww <- t(XXwotNA*weights)%*%YwotNA/(t(XXNA*weights)%*%YwotNA^2)
 if (pvals.expli) {
 tempvalpvalstep <- 2 * pnorm(-abs(tempww)) 
 temppvalstep <- (tempvalpvalstep < alpha.pvals.expli)
-if(sparse&sparseStop){
-  if(sum(temppvalstep)==0L){
-    break_nt_sparse <- TRUE}
-  else 
-  {tempww[!temppvalstep] <- 0}}
+if(sparse){tempww[!temppvalstep] <- 0}
+if(sparseStop){if(sum(temppvalstep)==0L){break_nt_sparse <- TRUE}}
 res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
 res$pvalstep <- cbind(res$pvalstep,temppvalstep)
 }
@@ -203,11 +201,8 @@ for (jj in 1:(res$nc)) {
     tempvalpvalstep[jj] <- tmww[4]
     temppvalstep[jj] <- (tmww[4] < alpha.pvals.expli)
 }
-if(sparse&sparseStop){
-  if(sum(temppvalstep)==0L){
-    break_nt_sparse <- TRUE}
-  else 
-  {tempww[!temppvalstep] <- 0}}
+if(sparse){tempww[!temppvalstep] <- 0}
+if(sparseStop){if(sum(temppvalstep)==0L){break_nt_sparse <- TRUE}}
 XXwotNA[!XXNA] <- 0
 rm(jj)
 res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
@@ -241,11 +236,8 @@ for (jj in 1:(res$nc)) {
     tempvalpvalstep[jj] <- 2 * pnorm(-abs(tmww[3])) 
     temppvalstep[jj] <- (tempvalpvalstep[jj] < alpha.pvals.expli)
 }
-if(sparse&sparseStop){
-      if(sum(temppvalstep)==0L){
-        break_nt_sparse <- TRUE}
-      else 
-      {tempww[!temppvalstep] <- 0}}
+if(sparse){tempww[!temppvalstep] <- 0}
+if(sparseStop){if(sum(temppvalstep)==0L){break_nt_sparse <- TRUE}}
 XXwotNA[!XXNA] <- 0
 rm(jj,tts)
 res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
@@ -283,6 +275,7 @@ for (jj in 1:(res$nc)) {
 res$residXX <- XXwotNA-temptt%*%temppp
 
 if (na.miss.X & !na.miss.Y) {
+  if(sparse==FALSE){
 for (ii in 1:res$nr) {
 if(rcond(t(cbind(res$pp,temppp)[XXNA[ii,],,drop=FALSE])%*%cbind(res$pp,temppp)[XXNA[ii,],,drop=FALSE])<tol_Xi) {
 break_nt <- TRUE; res$computed_nt <- kk-1
@@ -294,9 +287,11 @@ break
 rm(ii)
 if(break_nt==TRUE) {break}
 }
+}
 
 if(!PredYisdataX){
 if (na.miss.PredictY & !na.miss.Y) {
+  if(sparse==FALSE){    
 for (ii in 1:nrow(PredictYwotNA)) {
 if(rcond(t(cbind(res$pp,temppp)[PredictYNA[ii,],,drop=FALSE])%*%cbind(res$pp,temppp)[PredictYNA[ii,],,drop=FALSE])<tol_Xi) {
 break_nt <- TRUE; res$computed_nt <- kk-1
@@ -309,6 +304,7 @@ rm(ii)
 if(break_nt==TRUE) {break}
 }
 }
+}
 
 
 
@@ -371,9 +367,9 @@ res$ChisqPearson <- crossprod(residuals.glm(tempconstglm,type="pearson"))
 res$MissClassed <- sum(unclass(res$RepY)!=ifelse(predict(tempconstglm,type="response") < 0.5, 0,1))
 #}
 rm(tempconstglm)
-tt<-res$tt
-tempregglm <- glm(YwotNA~tt,family=family)
-rm(tt)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+tempregglm <- glm(YwotNA~.,data=tttrain,family=family)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregglm))
 res$BIC <- cbind(res$BIC,AIC(tempregglm, k = log(res$nr)))
 res$Coeffsmodel_vals <- cbind(res$Coeffsmodel_vals,rbind(summary(tempregglm)$coefficients,matrix(rep(NA,4*(nt-kk)),ncol=4)))
@@ -388,9 +384,9 @@ res$CoeffConstante <- tempCoeffConstante
 tempCoeffC <- tempCoeffC[-1]
 } else {
 if (!(na.miss.X | na.miss.Y)) {
-tt<-res$tt
-tempregglm <- glm(YwotNA~tt,family=family)
-rm(tt)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+tempregglm <- glm(YwotNA~.,data=tttrain,family=family)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregglm))
 res$BIC <- cbind(res$BIC,AIC(tempregglm, k = log(res$nr)))
 res$Coeffsmodel_vals <- cbind(res$Coeffsmodel_vals,rbind(summary(tempregglm)$coefficients,matrix(rep(NA,4*(nt-kk)),ncol=4)))
@@ -406,9 +402,9 @@ tempCoeffC <- tempCoeffC[-1]
 }
 else
 {
-tt<-res$tt
-tempregglm <- glm(YwotNA~tt,family=family)
-rm(tt)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+tempregglm <- glm(YwotNA~.,data=tttrain,family=family)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregglm))
 res$BIC <- cbind(res$BIC,AIC(tempregglm, k = log(res$nr)))
 res$Coeffsmodel_vals <- cbind(res$Coeffsmodel_vals,rbind(summary(tempregglm)$coefficients,matrix(rep(NA,4*(nt-kk)),ncol=4)))
@@ -458,9 +454,9 @@ tempm <- model.frame(tempfff, tempmodord)
 tempmat <- model.matrix(tempfff, model.frame(tempfff, tempmodord))
 res$ChisqPearson <- sum(Chiscompmatrix(as.list(as.data.frame(t(predict(tempconstpolr,type="probs")))),as.list(as.data.frame(t(tempmat)))))
 rm(tempconstpolr)
-tts<-res$tt
-tempregpolr <- MASS::polr(YwotNA~tts,na.action=na.exclude,Hess=TRUE,method=method)
-rm(tts)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+tempregpolr <- MASS::polr(YwotNA~.,data=tttrain,na.action=na.exclude,Hess=TRUE,method=method)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregpolr))
 res$BIC <- cbind(res$BIC,AIC(tempregpolr, k = log(res$nr)))
 res$MissClassed <- cbind(res$MissClassed,sum(!(unclass(predict(tempregpolr,type="class"))==unclass(res$RepY))))
@@ -476,9 +472,9 @@ res$CoeffCFull <- matrix(c(tempCoeffConstante,tempCoeffC,rep(NA,nt-kk)),ncol=1)
 res$CoeffConstante <- tempCoeffConstante
 } else {
 if (!(na.miss.X | na.miss.Y)) {
-tts <- res$tt
-tempregpolr <- MASS::polr(YwotNA~tts,na.action=na.exclude,Hess=TRUE,method=method)
-rm(tts)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+tempregpolr <- MASS::polr(YwotNA~.,data=tttrain,na.action=na.exclude,Hess=TRUE,method=method)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregpolr))
 res$BIC <- cbind(res$BIC,AIC(tempregpolr, k = log(res$nr)))
 res$MissClassed <- cbind(res$MissClassed,sum(!(unclass(predict(tempregpolr,type="class"))==unclass(res$RepY))))
@@ -495,9 +491,9 @@ res$CoeffConstante <- cbind(res$CoeffConstante,tempCoeffConstante)
 }
 else
 {
-tts<-res$tt
-tempregpolr <- MASS::polr(YwotNA~tts,na.action=na.exclude,Hess=TRUE,method=method)
-rm(tts)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+tempregpolr <- MASS::polr(YwotNA~.,data=tttrain,na.action=na.exclude,Hess=TRUE,method=method)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregpolr))
 res$BIC <- cbind(res$BIC,AIC(tempregpolr, k = log(res$nr)))
 res$MissClassed <- cbind(res$MissClassed,sum(!(unclass(predict(tempregpolr,type="class"))==unclass(res$RepY))))
@@ -894,15 +890,14 @@ res$Coeffsmodel_vals<-res$Coeffsmodel_vals[1:(dim(res$Coeffsmodel_vals)[1]-(nt-r
 if (!(na.miss.PredictY | na.miss.Y)) {
 cat("____Predicting X without NA neither in X nor in Y____\n")
 res$ttPredictY <- PredictYwotNA%*%res$wwetoile 
-colnames(res$ttPredictY) <- paste("tt",1:res$computed_nt,sep="")
-}
+colnames(res$ttPredictY) <- NULL}
 else {
 if (na.miss.PredictY & !na.miss.Y) {
 cat("____Predicting X with NA in X and not in Y____\n")
 for (ii in 1:nrow(PredictYwotNA)) {  
       res$ttPredictY <- rbind(res$ttPredictY,t(solve(t(res$pp[PredictYNA[ii,],,drop=FALSE])%*%res$pp[PredictYNA[ii,],,drop=FALSE])%*%t(res$pp[PredictYNA[ii,],,drop=FALSE])%*%(PredictYwotNA[ii,])[PredictYNA[ii,]]))
 }
-colnames(res$ttPredictY) <- paste("tt",1:res$computed_nt,sep="")
+colnames(res$ttPredictY) <- NULL
 }
 else {
 cat("____There are some NAs both in X and Y____\n")
@@ -1008,9 +1003,9 @@ if (modele %in% c("pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-i
 res$YChapeau <- as.matrix(tempregglm$fitted.values)            
 rownames(res$YChapeau) <- rownames(ExpliX)
 
-tt <- res$ttPredictY
-res$Std.ValsPredictY <- predict(tempregglm,newdata=data.frame(tt))
-res$ValsPredictY <- predict(tempregglm,newdata=data.frame(tt),type = "response")
+ttpred <- data.frame(tt=res$ttPredictY)
+res$Std.ValsPredictY <- predict(tempregglm,newdata=ttpred)
+res$ValsPredictY <- predict(tempregglm,newdata=ttpred,type = "response")
 
 res$Std.XChapeau <- res$tt%*%t(res$pp)
 rownames(res$Std.XChapeau) <- rownames(ExpliX)
@@ -1028,26 +1023,28 @@ res$YChapeau <- tempregpolr$fitted.values
 res$YChapeauCat <- predict(tempregpolr,type="class")
 rownames(res$YChapeau) <- rownames(ExpliX)
 
-res$ValsPredictY <- predict(tempregpolr, data.frame(tts=I(res$ttPredictY)),type="probs")
-res$ValsPredictYCat <- predict(tempregpolr, data.frame(tts=I(res$ttPredictY)),type="class")
+ttpred <- data.frame(tt=res$ttPredictY)
+res$ValsPredictY <- predict(tempregpolr, newdata=ttpred,type="probs")
+res$ValsPredictYCat <- predict(tempregpolr, newdata=ttpred,type="class")
 
 res$Std.XChapeau <- res$tt%*%t(res$pp)
 rownames(res$Std.XChapeau) <- rownames(ExpliX)
-names(res$CoeffC) <- paste("Coeff_Comp_Reg",1:res$computed_nt)
+names(res$CoeffC) <- paste("Coeff_Comp_Reg",1:res$computed_nt,sep="")
 res$FinalModel <- tempregpolr
 }
 
 
+colnames(res$ttPredictY) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$pp) <- colnames(ExpliX)
-colnames(res$pp) <- paste("Comp_",1:res$computed_nt)
+colnames(res$pp) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$ww) <- colnames(ExpliX)
-colnames(res$ww) <- paste("Comp_",1:res$computed_nt)
+colnames(res$ww) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$wwnorm) <- colnames(ExpliX)
-colnames(res$wwnorm) <- paste("Comp_",1:res$computed_nt)
+colnames(res$wwnorm) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$wwetoile) <- colnames(ExpliX)
-colnames(res$wwetoile) <- paste("Coord_Comp_",1:res$computed_nt)
+colnames(res$wwetoile) <- paste("Coord_Comp_",1:res$computed_nt,sep="")
 rownames(res$tt) <- rownames(ExpliX)
-colnames(res$tt) <- paste("Comp_",1:res$computed_nt)
+colnames(res$tt) <- paste("Comp_",1:res$computed_nt,sep="")
 res$XXwotNA <- XXwotNA
 cat("****________________________________________________****\n")
 cat("\n")
