@@ -1,4 +1,4 @@
-PLS_glm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,subset,start=NULL,etastart,mustart,offset,method,control= list(),contrasts=NULL,sparse=FALSE,sparseStop=TRUE,naive=FALSE) {  
+PLS_glm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,subset,start=NULL,etastart,mustart,offset,method,control= list(),contrasts=NULL,sparse=FALSE,sparseStop=FALSE,naive=FALSE) {  
 
 
 ##################################################
@@ -9,7 +9,8 @@ PLS_glm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=d
 
 cat("____************************************************____\n")
 if(is.null(modele)){naive=FALSE} else {if(modele=="pls"){naive=FALSE} else {if(!missing(naive)){cat(paste("Only naive DoF can be used with PLS GLM\n",sep=""))}; naive=TRUE}}
-if(sparse){pvals.expli=TRUE}
+if(sparse){sparseStop=TRUE}
+if(sparseStop){pvals.expli=TRUE}
 
 if (missing(data)) {data <- environment(formula)}
 mf <- mf2 <- match.call(expand.dots = FALSE)
@@ -66,14 +67,14 @@ if(any(apply(is.na(dataX),MARGIN=2,"all"))){return(vector("list",0)); cat("One o
 if(any(apply(is.na(dataX),MARGIN=1,"all"))){return(vector("list",0)); cat("One of the rows of dataX is completely filled with missing data"); stop()}
 if(identical(dataPredictY,dataX)){PredYisdataX <- TRUE} else {PredYisdataX <- FALSE}
 if(!PredYisdataX){
-if(any(apply(is.na(dataPredictY),MARGIN=2,"all"))){return(vector("list",0)); cat("One of the columns of dataPredictY is completely filled with missing data"); stop()}
+#if(any(apply(is.na(dataPredictY),MARGIN=2,"all"))){return(vector("list",0)); cat("One of the columns of dataPredictY is completely filled with missing data"); stop()}
 if(any(apply(is.na(dataPredictY),MARGIN=1,"all"))){return(vector("list",0)); cat("One of the rows of dataPredictY is completely filled with missing data"); stop()}
 }
 
 if(any(is.na(dataX))) {na.miss.X <- TRUE} else na.miss.X <- FALSE
 if(any(is.na(dataY))) {na.miss.Y <- TRUE} else na.miss.Y <- FALSE
 if(any(is.na(dataPredictY))) {na.miss.PredictY <- TRUE} else {na.miss.PredictY <- FALSE}
-if(na.miss.X|na.miss.Y){naive=TRUE; cat(paste("Only naive DoF can be used with missing data\n",sep="")); if(!NoWeights){cat(paste("Weights cannot be used with missing data\n",sep=""))}}
+if(na.miss.X|na.miss.Y){naive=TRUE; cat(paste("Only naive DoF can be used with missing data\n",sep="")); if(!NoWeights){cat(paste("Weights cannot be used with missing data\n",sep=""))};  if(sparse){cat(paste("sparse option cannot be used with missing data\n",sep="")); sparse=FALSE}}
 
 if (!is.data.frame(dataX)) {dataX <- data.frame(dataX)}
 if (is.null(modele) & !is.null(family)) {modele<-"pls-glm-family"}
@@ -220,11 +221,8 @@ tempww <- t(XXwotNA*weights)%*%YwotNA/(t(XXNA*weights)%*%YwotNA^2)
 if (pvals.expli) {
 tempvalpvalstep <- 2 * pnorm(-abs(tempww)) 
 temppvalstep <- (tempvalpvalstep < alpha.pvals.expli)
-if(sparse&sparseStop){
-  if(sum(temppvalstep)==0L){
-    break_nt_sparse <- TRUE}
-  else 
-  {tempww[!temppvalstep] <- 0}}
+if(sparse){tempww[!temppvalstep] <- 0}
+if(sparseStop){if(sum(temppvalstep)==0L){break_nt_sparse <- TRUE}}
 res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
 res$pvalstep <- cbind(res$pvalstep,temppvalstep)
 }
@@ -254,11 +252,8 @@ for (jj in 1:(res$nc)) {
     tempvalpvalstep[jj] <- tmww[4]
     temppvalstep[jj] <- (tmww[4] < alpha.pvals.expli)
 }
-if(sparse&sparseStop){
-  if(sum(temppvalstep)==0L){
-    break_nt_sparse <- TRUE}
-  else 
-  {tempww[!temppvalstep] <- 0}}
+if(sparse){tempww[!temppvalstep] <- 0}
+if(sparseStop){if(sum(temppvalstep)==0L){break_nt_sparse <- TRUE}}
 XXwotNA[!XXNA] <- 0
 rm(jj)
 res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
@@ -295,11 +290,8 @@ for (jj in 1:(res$nc)) {
     tempvalpvalstep[jj] <- 2 * pnorm(-abs(tmww[3])) 
     temppvalstep[jj] <- (tempvalpvalstep[jj] < alpha.pvals.expli)
 }
-if(sparse&sparseStop){
-      if(sum(temppvalstep)==0L){
-        break_nt_sparse <- TRUE}
-      else 
-      {tempww[!temppvalstep] <- 0}}
+if(sparse){tempww[!temppvalstep] <- 0}
+if(sparseStop){if(sum(temppvalstep)==0L){break_nt_sparse <- TRUE}}
 XXwotNA[!XXNA] <- 0
 rm(jj,tts)
 mf2$Hess <- FALSE
@@ -340,7 +332,8 @@ for (jj in 1:(res$nc)) {
 res$residXX <- XXwotNA-temptt%*%temppp
 
 if (na.miss.X & !na.miss.Y) {
-for (ii in 1:res$nr) {
+  if(sparse==FALSE){
+    for (ii in 1:res$nr) {
 if(rcond(t(cbind(res$pp,temppp)[XXNA[ii,],,drop=FALSE])%*%cbind(res$pp,temppp)[XXNA[ii,],,drop=FALSE])<tol_Xi) {
 break_nt <- TRUE; res$computed_nt <- kk-1
 cat(paste("Warning : reciprocal condition number of t(cbind(res$pp,temppp)[XXNA[",ii,",],,drop=FALSE])%*%cbind(res$pp,temppp)[XXNA[",ii,",],,drop=FALSE] < 10^{-12}\n",sep=""))
@@ -351,8 +344,10 @@ break
 rm(ii)
 if(break_nt==TRUE) {res$computed_nt <- kk-1;break}
 }
+}
 
 if(!PredYisdataX){
+  if(sparse==FALSE){
 if (na.miss.PredictY & !na.miss.Y) {
 for (ii in 1:nrow(PredictYwotNA)) {
 if(rcond(t(cbind(res$pp,temppp)[PredictYNA[ii,],,drop=FALSE])%*%cbind(res$pp,temppp)[PredictYNA[ii,],,drop=FALSE])<tol_Xi) {
@@ -366,6 +361,7 @@ rm(ii)
 if(break_nt==TRUE) {res$computed_nt <- kk-1;break}
 }
 }
+}
 
 
 res$ww <- cbind(res$ww,tempww)
@@ -430,12 +426,13 @@ res$ChisqPearson <- crossprod(residuals.glm(tempconstglm,type="pearson"))
 res$MissClassed <- sum(unclass(res$RepY)!=ifelse(predict(tempconstglm,type="response") < 0.5, 0,1))
 #}
 rm(tempconstglm)
-tt<-res$tt
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+mf2$data <- tttrain  
 mf2$model <- TRUE
-mf2[[2]]<-YwotNA~tt
+mf2[[2]]<-YwotNA~.
 tempregglm <- eval(mf2, parent.frame(n=sys.nframe()))
 mf2$model <- FALSE
-rm(tt)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregglm))
 res$BIC <- cbind(res$BIC,AIC(tempregglm, k = log(res$nr)))
 res$Coeffsmodel_vals <- cbind(res$Coeffsmodel_vals,rbind(summary(tempregglm)$coefficients,matrix(rep(NA,4*(nt-kk)),ncol=4)))
@@ -450,12 +447,13 @@ res$CoeffConstante <- tempCoeffConstante
 tempCoeffC <- tempCoeffC[-1]
 } else {
 if (!(na.miss.X | na.miss.Y)) {
-tt<-res$tt
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+mf2$data <- tttrain  
 mf2$model <- TRUE
-mf2[[2]]<-YwotNA~tt
+mf2[[2]]<-YwotNA~.
 tempregglm <- eval(mf2, parent.frame(n=sys.nframe()))
 mf2$model <- FALSE
-rm(tt)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregglm))
 res$BIC <- cbind(res$BIC,AIC(tempregglm, k = log(res$nr)))
 res$Coeffsmodel_vals <- cbind(res$Coeffsmodel_vals,rbind(summary(tempregglm)$coefficients,matrix(rep(NA,4*(nt-kk)),ncol=4)))
@@ -471,12 +469,13 @@ tempCoeffC <- tempCoeffC[-1]
 }
 else
 {
-tt<-res$tt
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
+mf2$data <- tttrain  
 mf2$model <- TRUE
-mf2[[2]]<-YwotNA~tt
+mf2[[2]]<-YwotNA~.
 tempregglm <- eval(mf2, parent.frame(n=sys.nframe()))
 mf2$model <- FALSE
-rm(tt)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregglm))
 res$BIC <- cbind(res$BIC,AIC(tempregglm, k = log(res$nr)))
 res$Coeffsmodel_vals <- cbind(res$Coeffsmodel_vals,rbind(summary(tempregglm)$coefficients,matrix(rep(NA,4*(nt-kk)),ncol=4)))
@@ -531,14 +530,15 @@ tempm <- model.frame(tempfff, tempmodord)
 tempmat <- model.matrix(tempfff, model.frame(tempfff, tempmodord))
 res$ChisqPearson <- sum(Chiscompmatrix(as.list(as.data.frame(t(predict(tempconstpolr,type="probs")))),as.list(as.data.frame(t(tempmat)))))
 rm(tempconstpolr)
-tts<-res$tt
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
 mf2$model <- TRUE
 mf2$Hess <- TRUE
-mf2[[2]]<-YwotNA~tts
+mf2[[2]]<-YwotNA~.
+mf2$data <- tttrain
 tempregpolr <- eval(mf2, parent.frame(n=sys.nframe()))
 mf2$model <- FALSE
 mf2$Hess <- FALSE
-rm(tts)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregpolr))
 res$BIC <- cbind(res$BIC,AIC(tempregpolr, k = log(res$nr)))
 res$MissClassed <- cbind(res$MissClassed,sum(!(unclass(predict(tempregpolr,type="class"))==unclass(res$RepY))))
@@ -554,14 +554,15 @@ res$CoeffCFull <- matrix(c(tempCoeffConstante,tempCoeffC,rep(NA,nt-kk)),ncol=1)
 res$CoeffConstante <- tempCoeffConstante
 } else {
 if (!(na.miss.X | na.miss.Y)) {
-tts <- res$tt
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
 mf2$model <- TRUE
 mf2$Hess <- TRUE
-mf2[[2]]<-YwotNA~tts
+mf2[[2]]<-YwotNA~.
+mf2$data <- tttrain
 tempregpolr <- eval(mf2, parent.frame(n=sys.nframe()))
 mf2$model <- FALSE
 mf2$Hess <- FALSE
-rm(tts)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregpolr))
 res$BIC <- cbind(res$BIC,AIC(tempregpolr, k = log(res$nr)))
 res$MissClassed <- cbind(res$MissClassed,sum(!(unclass(predict(tempregpolr,type="class"))==unclass(res$RepY))))
@@ -578,14 +579,16 @@ res$CoeffConstante <- cbind(res$CoeffConstante,tempCoeffConstante)
 }
 else
 {
-tts<-res$tt
+rm(tempconstpolr)
+tttrain<-data.frame(YwotNA=YwotNA,tt=res$tt)
 mf2$model <- TRUE
 mf2$Hess <- TRUE
-mf2[[2]]<-YwotNA~tts
+mf2[[2]]<-YwotNA~.
+mf2$data <- tttrain
 tempregpolr <- eval(mf2, parent.frame(n=sys.nframe()))
 mf2$model <- FALSE
 mf2$Hess <- FALSE
-rm(tts)
+rm(tttrain)
 res$AIC <- cbind(res$AIC,AIC(tempregpolr))
 res$BIC <- cbind(res$BIC,AIC(tempregpolr, k = log(res$nr)))
 res$MissClassed <- cbind(res$MissClassed,sum(!(unclass(predict(tempregpolr,type="class"))==unclass(res$RepY))))
@@ -978,7 +981,7 @@ res$Coeffsmodel_vals<-res$Coeffsmodel_vals[1:(dim(res$Coeffsmodel_vals)[1]-(nt-r
 if (!(na.miss.PredictY | na.miss.Y)) {
 cat("____Predicting X without NA neither in X or Y____\n")
 res$ttPredictY <- PredictYwotNA%*%res$wwetoile 
-colnames(res$ttPredictY) <- paste("tt",1:res$computed_nt,sep="")
+colnames(res$ttPredictY) <- NULL
 }
 else {
 if (na.miss.PredictY & !na.miss.Y) {
@@ -986,7 +989,7 @@ cat("____Predicting X with NA in X and not in Y____\n")
 for (ii in 1:nrow(PredictYwotNA)) {  
       res$ttPredictY <- rbind(res$ttPredictY,t(solve(t(res$pp[PredictYNA[ii,],,drop=FALSE])%*%res$pp[PredictYNA[ii,],,drop=FALSE])%*%t(res$pp[PredictYNA[ii,],,drop=FALSE])%*%(PredictYwotNA[ii,])[PredictYNA[ii,]]))
 }
-colnames(res$ttPredictY) <- paste("tt",1:res$computed_nt,sep="")
+colnames(res$ttPredictY) <- NULL
 }
 else {
 cat("____There are some NAs both in X and Y____\n")
@@ -1092,9 +1095,9 @@ if (modele %in% c("pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-i
 res$YChapeau <- as.matrix(tempregglm$fitted.values)            
 rownames(res$YChapeau) <- rownames(ExpliX)
 
-tt <- res$ttPredictY
-res$Std.ValsPredictY <- predict(tempregglm,newdata=data.frame(tt))
-res$ValsPredictY <- predict(tempregglm,newdata=data.frame(tt),type = "response")
+ttpred <- data.frame(tt=res$ttPredictY)
+res$Std.ValsPredictY <- predict(tempregglm,newdata=ttpred)
+res$ValsPredictY <- predict(tempregglm,newdata=ttpred,type = "response")
 
 res$Std.XChapeau <- res$tt%*%t(res$pp)
 rownames(res$Std.XChapeau) <- rownames(ExpliX)
@@ -1112,26 +1115,28 @@ res$YChapeau <- tempregpolr$fitted.values
 res$YChapeauCat <- predict(tempregpolr,type="class")
 rownames(res$YChapeau) <- rownames(ExpliX)
 
-res$ValsPredictY <- predict(tempregpolr, data.frame(tts=I(res$ttPredictY)),type="probs")
-res$ValsPredictYCat <- predict(tempregpolr, data.frame(tts=I(res$ttPredictY)),type="class")
+ttpred <- data.frame(tt=res$ttPredictY)
+res$ValsPredictY <- predict(tempregpolr, data=ttpred,type="probs")
+res$ValsPredictYCat <- predict(tempregpolr, data=ttpred,type="class")
 
 res$Std.XChapeau <- res$tt%*%t(res$pp)
 rownames(res$Std.XChapeau) <- rownames(ExpliX)
-names(res$CoeffC) <- paste("Coeff_Comp_Reg",1:res$computed_nt)
+names(res$CoeffC) <- paste("Coeff_Comp_Reg",1:res$computed_nt,sep="")
 res$FinalModel <- tempregpolr
 }
 
 
+colnames(res$ttPredictY) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$pp) <- colnames(ExpliX)
-colnames(res$pp) <- paste("Comp_",1:res$computed_nt)
+colnames(res$pp) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$ww) <- colnames(ExpliX)
-colnames(res$ww) <- paste("Comp_",1:res$computed_nt)
+colnames(res$ww) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$wwnorm) <- colnames(ExpliX)
-colnames(res$wwnorm) <- paste("Comp_",1:res$computed_nt)
+colnames(res$wwnorm) <- paste("Comp_",1:res$computed_nt,sep="")
 rownames(res$wwetoile) <- colnames(ExpliX)
-colnames(res$wwetoile) <- paste("Coord_Comp_",1:res$computed_nt)
+colnames(res$wwetoile) <- paste("Coord_Comp_",1:res$computed_nt,sep="")
 rownames(res$tt) <- rownames(ExpliX)
-colnames(res$tt) <- paste("Comp_",1:res$computed_nt)
+colnames(res$tt) <- paste("Comp_",1:res$computed_nt,sep="")
 res$XXwotNA <- XXwotNA
 cat("****________________________________________________****\n")
 cat("\n")
